@@ -1,16 +1,14 @@
 """# Exporter
 """
 import ast
-import logging
 import sys
-import traitlets.config
-from nbconvert import exporters
+from nbconvert.exporters import PythonExporter
 from traitlets import List, default, import_item
-from .preprocessor import LiteraryTagAllowListPreprocessor
+from traitlets.config import Config
+from .preprocessor import TagAllowListPreprocessor
 from .utils import escape_triple_quotes, unparse_ast
-logger = logging.getLogger(__name__)
 
-class LiteraryPythonExporter(exporters.PythonExporter):
+class LiteraryExporter(PythonExporter):
 
     def __init__(self, *args, **kwargs):
         """
@@ -41,7 +39,7 @@ class LiteraryPythonExporter(exporters.PythonExporter):
 
     @default('default_preprocessors')
     def _default_preprocessors_default(self):
-        return [LiteraryTagAllowListPreprocessor]
+        return [TagAllowListPreprocessor]
 
     @default('exclude_input_prompt')
     def _exclude_input_prompt_default(self):
@@ -49,7 +47,7 @@ class LiteraryPythonExporter(exporters.PythonExporter):
 
     @property
     def default_config(self):
-        c = traitlets.config.Config({'LiteraryTagAllowListPreprocessor': {'enabled': True}})
+        c = Config({'TagAllowListPreprocessor': {'enabled': True}})
         c.merge(super().default_config)
         return c
 
