@@ -1,9 +1,9 @@
 """"""
-import traitlets
-from nbconvert import preprocessors
+from nbconvert.preprocessors import Preprocessor
+from traitlets import Set, Unicode
 
-class LiteraryTagAllowListPreprocessor(preprocessors.Preprocessor):
-    allow_cell_tags = traitlets.Set(traitlets.Unicode(), default_value={'export', 'docstring'})
+class TagAllowListPreprocessor(Preprocessor):
+    allow_cell_tags = Set(Unicode(), default_value={'export', 'docstring'})
 
     def check_cell_conditions(self, cell, resources: dict, index: int) -> bool:
         tags = cell.metadata.get('tags', [])
