@@ -1,6 +1,7 @@
 """"""
 from typing import Callable, Type, TypeVar
 T = TypeVar('T')
+WRAPPER_NAMES = ('fget', 'fset', 'fdel', '__func__', 'func')
 
 def patch(cls: Type) -> Callable[[T], T]:
     """Decorator to monkey-patch additional methods to a class.
@@ -16,7 +17,7 @@ def patch(cls: Type) -> Callable[[T], T]:
         try:
             return func.__name__
         except AttributeError:
-            for attr in ('fget', 'fset', 'fdel', '__func__'):
+            for attr in WRAPPER_NAMES:
                 try:
                     return getattr(func, attr).__name__
                 except AttributeError:
